Schedule
========

.. autoclass:: moco_wrapper.models.Schedule
    :members:

.. autoclass:: moco_wrapper.models.schedule.ScheduleAbsenceCode
   :members:
   :undoc-members:

.. autoclass:: moco_wrapper.models.schedule.ScheduleSymbol
   :members:
   :undoc-members: